#ifndef NT2_INCLUDE_FUNCTIONS_J1_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_J1_HPP_INCLUDED

#include <nt2/bessel/include/functions/j1.hpp>

#endif
